# nodejs16-oracledb.spec
#
# Builds the node-oracledb driver for Node.js 16
#
%global debug_package %{nil}

# A zip file downloaded from the node-oracledb github tag should be in
# SOURCES/node-oracledb-x.y.z.zip

# The version of node-oracledb extension being installed
%define nodeoracledbver 6.9.0

# The Node.js version
%define nodejsmainver 18
%define nextnodejsver 20
%define nodejsver %{nodejsmainver}.19.0


# odpi as a seperate package
%define odpiver 5.6.1
# Can't use %%{_libdir} since it is /usr/lib64
%define mylibdir /usr/local/lib/node_modules


# Test DB connection string and SYSTEM password
%define connectstring  localhost/orcl
%define systempw oracle

Summary: The node-oracledb add-on allows Node.js applications to connect to Oracle Database
Name: node-oracledb-node%{nodejsmainver}
Group: Development/Languages
Version: %{nodeoracledbver}
Release: 1%{?dist}
License: Apache 2.0
URL: https://github.com/oracle/node-oracledb/

# This is the GitHub URL to pull from:
#   https://github.com/oracle/node-oracledb/archive/v%%{nodeoracledbver}.zip
# The file name that is downloaded from that GitHub URL needs to be used:
Source0: oracledb-src-%{nodeoracledbver}.tar.bz2
Source1: createtestuser.sql
Source2: droptestuser.sql
Source3: node-v%{nodejsver}-headers.tar.gz

%if %{?rhel} == 7
BuildRequires: nodejs >= %{nodejsmainver}, nodejs < %{nextnodejsver}
Requires: nodejs >= %{nodejsmainver}, nodejs < %{nextnodejsver}
%else
BuildRequires: nodejs >= 1:%{nodejsmainver}, nodejs < 1:%{nextnodejsver}
BuildRequires: npm >= 6 
Requires: nodejs >= 1:%{nodejsmainver}, nodejs < 1:%{nextnodejsver}
Requires: npm >= 6
%endif

BuildRequires: gcc
BuildRequires: python3

%if %{?rhel} <= 8
BuildRequires: gcc-c++
%else
BuildRequires: g++
%endif


# Stop install of the generated RPM failing with the error: "Requires: libclntsh.so.12.1()(64bit)"
AutoReqProv: no

Provides: nodejs-oracledb = %{version}-%{release}
Obsoletes: node-oracledb-12c-node%{nodejsmainver}

%description
The node-oracledb add-on for Node.js powers high performance Oracle Database applications.
Please add %mylibdir to your env variable NODE_PATH.

%prep
%setup -n oracledb-src-%{nodeoracledbver}

%build
unset http_proxy
unset https_proxy

export no_proxy=localhost,127.0.0.1,oracle.com,oraclecorp.com
npm config set registry https://artifacthub-iad.oci.oraclecorp.com/api/npm/npmjs-remote/

%if %{nodejsmainver} < 18
npm config set python /usr/bin/python3
npm config set tarball  %{SOURCE3}
npm install %{_builddir}/oracledb-src-%{version} --verbose
%else
export npm_config_python=/usr/bin/python3
npm_config_tarball=%{SOURCE3} npm install %{_builddir}/oracledb-src-%{version} --verbose
%endif

%check
# Note this tests the install in the build dir, not the buildroot. The latter is packaged up.
runtests() {

    cd %{_builddir}/oracledb-src-%{nodeoracledbver}

   #export PATH=/usr/lib/oracle/%{ocimainver}/client64/bin:$PATH
   #export LD_LIBRARY_PATH=/usr/lib/oracle/%{ocimainver}/client64/lib:$LD_LIBRARY_PATH

    npm install mocha should async

    # Create a temporary DB user and run the tests
    export NODE_ORACLEDB_USER='nodetest'$$
    export NODE_ORACLEDB_PASSWORD=$NODE_ORACLEDB_USER
    export NODE_ORACLEDB_CONNECTIONSTRING=%{connectstring}
    sqlplus  -l system/%{systempw}@$NODE_ORACLEDB_CONNECTIONSTRING @%{_sourcedir}/createtestuser.sql $NODE_ORACLEDB_USER $NODE_ORACLEDB_PASSWORD
    cd %{_builddir}/oracledb-src-%{nodeoracledbver}/node_modules/oracledb
    npm test
    sqlplus -l system/%{systempw}@$NODE_ORACLEDB_CONNECTIONSTRING @%{_sourcedir}/droptestuser.sql $NODE_ORACLEDB_USER

}

# Comment out the following 'runtests' line to skip testing
#runtests

%install
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT

mkdir -p $RPM_BUILD_ROOT/%{mylibdir}/oracledb
cp -rf %{_builddir}/oracledb-src-%{nodeoracledbver}/lib $RPM_BUILD_ROOT/%{mylibdir}/oracledb
cp -rf %{_builddir}/oracledb-src-%{nodeoracledbver}/package $RPM_BUILD_ROOT/%{mylibdir}/oracledb
cp -f %{_builddir}/oracledb-src-%{nodeoracledbver}/{CHANGELOG.md,LICENSE.txt,NOTICE.txt,README.md,SECURITY.md,THIRD_PARTY_LICENSES.txt,binding.gyp,index.js,package.json} $RPM_BUILD_ROOT/%{mylibdir}/oracledb

mkdir -p $RPM_BUILD_ROOT/%{mylibdir}/oracledb/build/Release/
cp -rf %{_builddir}/oracledb-src-%{nodeoracledbver}/build/Release/*.node  $RPM_BUILD_ROOT/%{mylibdir}/oracledb/build/Release/

%clean
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
%{mylibdir}/oracledb/

%changelog
* Fri Jul 18 2025 EL Errata <el-errata_ww@oracle.com> 6.9.0-1
- Update node-oracledb to 6.9.0 and odpi to 5.6.1

* Tue Apr 8 2025 Youcef Barhdadi <youcef.barhdad@oracle.com> 6.8.0-2
- build for nodejs 22
- drop instantclient
- Add g++ as build dependency
- Fix some Warning

* Tue Feb 25 2025 EL Errata <el-errata_ww@oracle.com> 6.8.0-1
- Update node-oracledb to 6.8.0 

* Mon Feb 10 2025 EL Errata <el-errata_ww@oracle.com> 6.7.2-1
- Update node-oracledb to 6.7.2 

* Sun Dec 22 2024 EL Errata <el-errata_ww@oracle.com> 6.7.1-1
- Update node-oracledb to 6.7.1 

* Mon Nov 18 2024 EL Errata <el-errata_ww@oracle.com> 6.7.0-1
- Update node-oracledb to 6.7.0 

* Thu Jul 25 2024 EL Errata <el-errata_ww@oracle.com> 6.6.0-1
- Update node-oracledb to 6.6.0 

* Thu May 23 2024 EL Errata <el-errata_ww@oracle.com> 6.5.1-1
- Update node-oracledb to 6.5.1 

* Thu May 02 2024 EL Errata <el-errata_ww@oracle.com> 6.5.0-1
- Update node-oracledb to 6.5.0 

* Mon Mar 11 2024 EL Errata <el-errata_ww@oracle.com> 6.4.0-1
- Update node-oracledb to 6.4.0 and odpi to 5.2.0

* Thu Dec 21 2023 EL Errata <el-errata_ww@oracle.com> 6.3.0-1
- Update node-oracledb to 6.3.0 

* Wed Oct 11 2023 EL Errata <el-errata_ww@oracle.com> 6.2.0-1
- Update node-oracledb to 6.2.0 

* Wed Aug 30 2023 EL Errata <el-errata_ww@oracle.com> 6.1.0-1
- Update node-oracledb to 6.1.0 

* Fri Aug 25 2023 EL Errata <el-errata_ww@oracle.com> 6.0.3-1
- Update node-oracledb to 6.0.3 

* Wed Jul 05 2023 Alan Steinberg <alan.steinberg@oracle.com> 6.0.1-2
- Update node-oracledb to 6.0.2

* Wed Jun 07 2023 Alan Steinberg <alan.steinberg@oracle.com> 6.0.1-1
- Update node-oracledb to 6.0.1

* Thu Jun 01 2023 Alan Steinberg <alan.steinberg@oracle.com> 6.0.0-1
- Update node-oracledb to 6.0.0.

* Fri Sep 09 2022 Alan Steinberg <alan.steinberg@oracle.com> 5.5.0-1
- Update node-oracledb to 5.5.0 and odpi to latest

* Fri Dec 17 2021 Qing Lin <qing.lin@oracle.com> 5.3.0-1
- Build for nodejs-16

* Fri Oct 22 2021 Alan Steinberg <alan.steinberg@oracle.com> 5.3.0-1
- Update node-oracledb to 5.3.0 and odpi to latest

* Wed Jun 16 2021 Alan Steinberg <alan.steinberg@oracle.com> 5.2.0-1.0.1
- Added support for aarch64.

* Sat Jun 05 2021 EL Errata <el-errata_ww@oracle.com> 5.2.0-1
- Update node-oracledb to 5.2.0 and odpi to 4.2.1

* Wed Mar 31 2021 Qing Lin <qing.lin@oracle.com> nodejs14-5.1.0-1.0.1
- Use "npm root -g" as the installation place [Orabug: 32710187]

* Mon Feb 22 2021 Qing Lin <qing.lin@oracle.com> nodejs14-5.1.0-1
- Simplify script based on node-oracledb document
- Update to 5.1.0

* Sat Nov 21 2020 Qing Lin <qing.lin@oracle.com> nodejs14-5.0.0-1
- Use nodejs-14 to build the 5.0.0.

* Tue Jul 07 2020 Qing Lin <qing.lin@oracle.com> 5.0.0-1.0.1
- Change dependency to libclntsh.so

* Mon Jun 29 2020 EL Errata <el-errata_ww@oracle.com> 5.0.0-1
- Update node-oracledb to 5.0.0 and odpi to 4.0.1

* Tue Jan 21 2020 EL Errata <el-errata_ww@oracle.com> 4.2.0-1
- Update to version 4.2.0
- Use internal npm registry

* Wed Dec 18 2019 Qing Lin <qing.lin@oracle.com> 4.1.0-1.0.1
- Update node-oracledb to 4.1.0 and odpi to 3.3.0

* Mon Nov 25 2019 EL Errata <el-errata_ww@oracle.com> 4.1.0-1
- Update node-oracledb to 4.1.0 and odpi to 3.2.2

* Sun Aug 18 2019 EL Errata <el-errata_ww@oracle.com> 4.0.1-1
- Update node-oracledb to 4.0.1 and odpi to 3.2.1

* Wed Jul 24 2019 EL Errata <el-errata_ww@oracle.com> 4.0.0-1
- Update node-oracledb to 4.0.0 and odpi to 3.2.0

* Thu Feb 21 2019 EL Errata <el-errata_ww@oracle.com> 3.1.2-1
- Update node-oracledb to 3.1.2 and odpi to 3.1.2

* Thu Jan 24 2019 EL Errata <el-errata_ww@oracle.com> 3.1.1-1
- Update to version 3.1.1

* Tue Jan 22 2019 EL Errata <el-errata_ww@oracle.com> 3.1.0-1
- Update node-oracledb to 3.1.0 and odpi to 3.1.0

* Wed Dec 05 2018 EL Errata <el-errata_ww@oracle.com> 3.0.1-1
- Update to version 3.0.1

* Tue Oct 02 2018 John Mcwalters <john.mcwalters@oracle.com> 3.0.0-1
- Update node-oracledb to 3.0.0 and odpi to 3.0.0
- Use instantclient version 18.3

* Fri Jun 08 2018 Srinivas Maturi <sriniva.maturi@oracle.com> - 2.3.0
-- upgrade to version 2.3.0, odpi to 2.4.0

* Tue Apr 3 2018 Qing Lin          <qing.lin@oracle.com>          - 2.2.0
  -- upgrade to version 2.2.0, odpi to 2.3.0

* Wed Mar 07 2018 Qing Lin          <qing.lin@oracle.com>          - 2.1.2
  -- upgrade to version 2.1.2

* Tue Feb 20 2018 Qing Lin          <qing.lin@oracle.com>          - 2.1.1
  -- upgrade to version 2.1.1.

* Mon Dec 18 2017 Qing Lin          <qing.lin@oracle.com>     	   - 2.0.15 
  -- setup auto-build 
  -- add package odpi as a source file.

* Thu Jun  8 2017 Qing Lin          <qing.lin@oracle.com>     	   - 1.13.1 setup auto-build
* Mon Jan 30 2017 P. Venkatraman    <p.venkatraman@oracle.com>     - 1.12.2
* Mon Jan 30 2017 P. Venkatraman    <p.venkatraman@oracle.com>     - 1.12.2
* Fri Nov  4 2016 Christopher Jones <christopher.jones@oracle.com> - Created
